@@ -1,10 +1,12 @@
 package Catalyst::View::Xslate;
 use Moose;
+use Moose::Util::TypeConstraints qw(coerce from where via subtype);
 use Encode;
 use Text::Xslate;
 use namespace::autoclean;
+use Scalar::Util qw/blessed weaken/;
 
-our $VERSION = '0.00008';
+our $VERSION = '0.00009';
 
 extends 'Catalyst::View';
 
@@ -91,17 +93,55 @@ has xslate => (
     clearer => 'clear_xslate',
 );
 
+my $expose_methods_tc = subtype 'HashRef', where { $_ };
+coerce $expose_methods_tc,
+  from 'ArrayRef',
+  via {
+    my %values = map { $_ => $_ } @$_;
+    return \%values;
+  };
+
+has expose_methods => (
+    is => 'ro',
+    isa => $expose_methods_tc,
+    predicate => 'has_expose_methods',
+    coerce => 1,
+);
+
 sub _build_xslate {
     my ($self, $c) = @_;
 
     my $name = $c;
     $name =~ s/::/_/g;
 
+    my $function = $self->function;
+    if ($self->has_expose_methods) {
+        my $meta = $self->meta;
+        my @names = keys %{$self->expose_methods};
+        foreach my $method_name (@names) {
+            my $method = $meta->find_method_by_name( $self->expose_methods->{$method_name} );
+            unless ($method) {
+                Catalyst::Exception->throw( "$method_name not found in Xslate view" );
+            }
+            my $method_body = $method->body;
+            my $weak_ctx = $c;
+            weaken $weak_ctx;
+
+            my $sub = sub {
+                $self->$method_body($weak_ctx, @_);
+            };
+
+            $function->{$method_name} = $function->{$method_name}
+              ? Catalyst::Exception->throw("$method_name can't be a method in the View and defined as a function.")
+              : $sub;
+        }
+    }
+
     my %args = (
         path      => $self->path || [ $c->path_to('root') ],
         cache_dir => $self->cache_dir || File::Spec->catdir(File::Spec->tmpdir, $name),
         cache     => $self->cache,
-        function  => $self->function,
+        function  => $function,
         module    => $self->module,
     );
 
@@ -164,14 +204,20 @@ sub process {
 sub render {
     my ($self, $c, $template, $vars) = @_;
 
+    $vars = $vars ? $vars : $c->stash;
+
     if ( ! $self->xslate ) {
         $self->_build_xslate( $c );
     }
 
     local $vars->{ $self->catalyst_var } =
         $vars->{ $self->catalyst_var } || $c;
-
-    return $self->xslate->render( $template, $vars );
+    
+    if(ref $template eq 'SCALAR') {
+        return $self->xslate->render_string( $$template, $vars );
+    } else {
+        return $self->xslate->render($template, $vars );
+    }
 }
 
 sub _rendering_error {
@@ -182,7 +228,6 @@ sub _rendering_error {
     return 0;
 }
 
-
 __PACKAGE__->meta->make_immutable();
 
 1;
@@ -196,8 +241,8 @@ Catalyst::View::Xslate - Text::Xslate View Class
 =head1 SYNOPSIS
 
     package MyApp::View::Xslate;
-    use strict;
-    use base qw(Catalyst::View::Xslate);
+    use Moose;
+    extends 'Catalyst::View::Xslate';
 
     1;
 
@@ -245,9 +290,58 @@ Use this to enable TT2 compatible variable methods via Text::Xslate::Bridge::TT2
         default => sub { [ 'Text::Xslate::Bridge::TT2Like' ] }
     );
 
-=head1 TODO
+=head2 expose_methods
 
-Currently there is no way to render a string.
+Use this option to specify methods from the View object to be exposed in the
+template. For example, if you have the following View:
+
+    package MyApp::View::Xslate;
+    use Moose;
+    extends 'Catalyst::View::Xslate';
+
+    sub foo {
+        my ( $self, $c, @args ) = @_;
+        return ...; # do something with $self, $c, @args
+    }
+
+then by setting expose_methods, you will be able to use foo() as a function in
+the template:
+
+    <: foo("a", "b", "c") # calls $view->foo( $c, "a", "b", "c" ) :>
+
+C<expose_methods> takes either a list of method names to expose, or a hash reference, in order to alias it differently in the template.
+
+    MyApp::View::Xslate->new(
+        # exposes foo(), bar(), baz() in the template
+        expose_methods => [ qw(foo bar baz) ]
+    );
+
+    MyApp::View::Xslate->new(
+        # exposes foo_alias(), bar_alias(), baz_alias() in the template,
+        # but they will in turn call foo(), bar(), baz(), on the view object.
+        expose_methods => {
+            foo => "foo_alias",
+            bar => "bar_alias",
+            baz => "baz_alias",
+        }
+    );
+
+=head1 METHODS
+
+=head1 C<$view->process($c)>
+
+Called by Catalyst.
+
+=head2 C<$view->render($c, $template, \%vars)>
+
+Renders the given C<$template> using variables \%vars.
+
+C<$template> can be a template file name, or a scalar reference to a template
+string.
+
+    $view->render($c, "/path/to/a/template.tx", \%vars );
+
+    $view->render($c, \'This is a xslate template!', \%vars );
 
 =head1 AUTHOR
 
